function c = getContours(d,x,y,V)
% c = getContours(f,x,y,V)
%
% getContours takes a function and a set of contour values, and returns the
% x and y values of that contour.
%
% Parameters:
%   f   :   A matrix approximating a two-dimensional function.
%   x   :   The x-values for the columns of f.
%   y   :   The y-values for the rows of f.
%   V   :   A vector of desired contour values.
%   c   :   If length(V) = 1, c(1,:) and c(2,:) are the x and y values of
%           the contour. Otherwise, c is a cell, and c{i}(1,:) and
%           c{i}(2,:) are the x and y values of the ith contour.

Vflag = 0;
if(length(V) == 1)
    V = [V V];
    Vflag = 1;
end
cn = contourc(x,y,d,V);
lencn = size(cn,2);
lenV = length(V);
c = cell(1,max([2 lenV]));

done = 0; 
next = 1;
indcn = 1;
nextorder = 0;
lastheight = nan;
while(~done)
    len = cn(2,indcn);
    height = cn(1,indcn);
    poly = cn(:,indcn+1:indcn+len);
    if(height ~= lastheight)
       nextorder = nextorder + 1;
       lastheight = height;
    end
    c{next} = poly;
    next = next + 1;
    indcn = indcn + len + 1;
    if(indcn >= lencn)
        done = 1;
    end
end
if(Vflag)
    c = c{1};
end
