%% Example code for BENG 260 Homework 3, Fall 2019
% Questions to mwagner@ucsd.edu or jmford@ucsd.edu
%
% We will do an analysis of a two-dimensional nonlinear ODE system.
% The equations that describe this system are:
%
%    Dx = -b*x -sin(y-a)
%    Dy = x

%%

close all; clear all

% 1. Use meshgrid to create an 2D matrix of (x,y) values:
%   Range:
%   -2  <=  x  <=  2
%   -pi <=  y  <=  pi
%   Parameter values:
%   b = 0;  a = 0;
%   b = 0;  a = pi/2;
%   b = 0;  a = pi;
%   b = 1;  a = pi/2;
%   b = 1;  a = pi;

% 2D-axis specification
N = 25;
x = linspace(-2,2,N);
y = linspace(-pi,pi,N);
[X, Y] = meshgrid(x,y);

% Constants
a = [0, pi/2, pi, pi/2, pi];
b = [0, 0, 0, 1, 1];

for i = 1:length(a)
    % Constants
    A = a(i);
    B = b(i);
    
    % 2D system of equations
    DX = -B*X - sin(Y-A);
    DY = X;
    
    % 2. Use getNullcline to get a pair of nullclines for each set of parameters. 
    [ncX_x, ncX_y] = getNullcline(DX,x,y);   % get X null-cline
    [ncY_x, ncY_y] = getNullcline(DY,x,y);   % get Y null-cline
    
    % 3. Use getCrossings to identify the fixed-points of the system
    [fp_x, fp_y] = getCrossings(ncX_x,ncX_y, ncY_x,ncY_y); 
    
    % 4. Try linearizing the system around the fixed-points using getJacobian. 
    %   Compute the eigenvalues of this matrix, using the eig 
    %   function or the SVD function. Make sure the eigenvalues confirm the 
    %   dynamics of the gradient map. 
    J = getJacobian(X,Y,DX,DY,fp_x,fp_y);
    [v, d] = eig(J);
    
    % Display eigenvalues of Jacobian matrix
    disp(['Eigenvalues of Jacobain for a = ', num2str(A), ', b = ', num2str(B)]) 
    disp(d);
    disp('');
    
    % Plot Gradients, Nullclines, Fixed-Points
    figure()
    axis square
    axis([x(1) x(end) y(1) y(end)]);
    hold on
    title(['Damped Nonlinear Pendulum System; a = ', num2str(A), ', b = ', num2str(B)]) 
    quiver(X,Y,DX,DY,2);                                        % gradients
    plot(ncX_x, ncX_y, 'k', ncY_x, ncY_y, 'k', 'linewidth', 2)  % nullclines
    plot(fp_x, fp_y, 'r*')                                      % fixed-point   
    xlabel('x'); ylabel('y')
    legend('Gradient','F(x,y) = 0','G(x,y) = 0');
end
